@@ -7,8 +7,26 @@
 //!
 //! Read more [here](https://github.com/aniketfuryrocks/gxi)
 
-#[cfg(feature = "desktop")]
-pub use gxi_desktop_binds::*;
-pub use gxi_interface::*;
-#[cfg(feature = "web")]
-pub use gxi_web_binds::*;
+#[cfg(all(feature = "web", feature = "desktop"))]
+compile_error!("Cannot enable both `web` and `desktop` features.");
+
+#[cfg(not(any(feature = "web", feature = "desktop")))]
+compile_error!("Either `web` or `desktop` feature must be enabled.");
+
+macro_rules! transparent_block {( $($tt:tt)* ) => ( $($tt)* )}
+
+#[cfg(any(feature = "web", feature = "desktop"))]
+#[cfg(not(all(feature = "web", feature = "desktop")))]
+transparent_block! {
+    mod parser_macros;
+    mod binds;
+    mod should_render;
+    mod nodes;
+    pub use binds::*;
+    pub use parser_macros::*;
+    pub use gxi_macro::gxi;
+    pub use nodes::*;
+    pub use should_render::*;
+
+    pub type AsyncResult<T> = Result<T, Box<dyn std::error::Error>>;
+}
